summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoOpenPane.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoOpenPane.h')
-rw-r--r--lib/kofficecore/KoOpenPane.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficecore/KoOpenPane.h b/lib/kofficecore/KoOpenPane.h
index d9abf832..0efad845 100644
--- a/lib/kofficecore/KoOpenPane.h
+++ b/lib/kofficecore/KoOpenPane.h
@@ -24,7 +24,7 @@
#include <koOpenPaneBase.h>
class KoCustomDocumentCreator;
-class KConfig;
+class TDEConfig;
class KoTemplateGroup;
class KoOpenPanePrivate;
class TDEInstance;
@@ -42,7 +42,7 @@ class KoOpenPane : public KoOpenPaneBase
/**
* Constructor
* @param parent the parent widget
* @param instance the TDEInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.
*/
KoOpenPane(TQWidget *parent, TDEInstance* instance, const TQString& templateType = TQString());
@@ -42,7 +42,7 @@ class KoOpenPane : public KoOpenPaneBase
* Constructor
* @param parent the parent widget
- * @param instance the TDEInstance to be used for KConfig data
+ * @param instance the TDEInstance to be used for TDEConfig data
* @param templateType the template-type (group) that should be selected on creation.
*/